@@ -1,5 +1,7 @@
 import json
-import httpx
+import requests
+import asyncio
+import functools
 
 
 class HTTPResponse:
@@ -7,6 +9,7 @@ class HTTPResponse:
         self.method = method.upper()
         self.status_message = None
         self.status_code = response.status_code
+        self.msg = response.reason
         self._response = response
         self._body_buffer = body_buffer
         self._buffer_pointer = 0
@@ -53,10 +56,11 @@ class HttpClient:
 
     async def get(self, request_uri, headers=None):
         request_uri = self._normalize_uri(request_uri)
-        async with httpx.AsyncClient(timeout=30) as client:
-            resp = await client.get(request_uri, headers=headers)
-            _body_buffer = resp.content
-            return HTTPResponse(resp, _body_buffer)
+        loop = asyncio.get_running_loop()
+        resp = await loop.run_in_executor(None, functools.partial(requests.get, request_uri, headers=headers))
+        # resp = requests.get(request_uri, headers=headers)
+        _body_buffer = resp.content
+        return HTTPResponse(resp, _body_buffer)
 
     async def post(self, request_uri, body=None, headers=None):
         request_uri = self._normalize_uri(request_uri)
@@ -66,7 +70,8 @@ class HttpClient:
             pass
         elif isinstance(body, str):
             raise TypeError("Unsupported type: " + str(type(body)))
-        async with httpx.AsyncClient(timeout=30) as client:
-            resp = await client.post(request_uri, data=body, headers=headers)
-            _body_buffer = resp.content
-            return HTTPResponse(resp, _body_buffer)
+        loop = asyncio.get_running_loop()
+        resp = await loop.run_in_executor(None, functools.partial(requests.post, request_uri, data=body, headers=headers))
+        # resp = requests.post(request_uri, data=body, headers=headers)
+        _body_buffer = resp.content
+        return HTTPResponse(resp, _body_buffer)
